Boleto bancário

| 104-0 | Recibo do Sacado

Cedente | Agência/Código Cedente 1565/123456-0 | CPF/CNPJ Cedente | Vencimento 08/07/2012
Sacado - CPF/CNPJ: | Nosso Número 14000008019525086-2 | N. do documento 270319510 | Data Documento 03/07/2012
Endereço Cedente - - - - | Valor Documento 2952,95

Demonstrativo
Autenticação Mecânica

| 104-0 | 10491.23456 60000.100846 01952.508644 3 53880000295295

Local de pagamento Preferencialmente nas Casas Lotéricas e Agências da Caixa | Vencimento 08/07/2012
Cedente | Agência/Código cedente 1565/123456-0
Data do documento 03/07/2012 | N. do documento 270319510 | Espécie doc | Aceite N | Data processamento 03/07/2012 | Nosso número 14000008019525086-2
Uso do banco | Carteira 1 | Espécie R$ | Quantidade | Valor | (=) Valor documento 2952,95
Instruções (Todas as informações deste bloqueto são de exclusiva responsabilidade do cedente) | (-) Descontos/Abatimentos
(-) Outras deduções
(+) Mora/Multa
(+) Outros acréscimos
(=) Valor cobrado

Sacado | - CPF/CNPJ: - - -
Sacador / Avalista | Código de baixa
| Autenticação Mecânica / Ficha de Compensação